Learn R Programming

ggRtsy (version 1.2.1)

scale_fill_gogh: Creating the color fill scale for Van Gogh Colors

Description

Creating the color fill scale for Van Gogh Colors

Usage

scale_fill_gogh(palette = "sunflowers", discrete = TRUE, reverse = FALSE, ...)

Value

No return value. Called for side effects.

Arguments

palette

Character name of palette in gogh_palettes_pop

discrete

Boolean if color aesthetic is discrete

reverse

Boolean if the palette should be reversed

...

Additional arguments used to discrete_scale() or scale_fill_gradientn() to automatically interpolate between colors.

Examples

Run this code
if (require(ggplot2)) {
  data <- data.frame(c = LETTERS[1:3],x = c(1,5,7),y = c(5,9,13))
  ggplot(data, aes(x,fill=c))+geom_bar()+scale_fill_gogh()
}

Run the code above in your browser using DataLab